#
# spec file for package mutt
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mutt
#!BuildIgnore:  sendmail
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cyrus-sasl-devel
BuildRequires:  cyrus-sasl-gssapi
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  fdupes
BuildRequires:  gdbm-devel
BuildRequires:  glibc-i18ndata
BuildRequires:  ispell
BuildRequires:  krb5-devel
BuildRequires:  libcom_err
%if 0%{?suse_version} <= 1230
BuildRequires:  libgcrypt
%else
BuildRequires:  libgcrypt-devel
%endif
BuildRequires:  libgnutls-devel
BuildRequires:  libgpg-error-devel
BuildRequires:  libidn-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libxml2
BuildRequires:  libxslt
BuildRequires:  lynx
BuildRequires:  ncurses-devel
BuildRequires:  postfix
BuildRequires:  sgml-skel
BuildRequires:  update-desktop-files
BuildRequires:  xli
#if
%if 0%{?suse_version} > 1130
BuildRequires:  libassuan-devel
BuildRequires:  libgpgme-devel
%else
BuildRequires:  gpgme-devel
%endif
Url:            http://www.mutt.org
Provides:       muttssl
Obsoletes:      muttssl
Recommends:     smtp_daemon
Recommends:     urlview
Recommends:     w3m
%if 0%{?suse_version} > 1130
Requires(post):   shared-mime-info
Requires(postun): shared-mime-info
%endif
# NOTE: We don't want this dependency and desktop-data-SuSE is in all
# desktop selections.
#Requires:    desktop-data-SuSE
Version:        1.5.24
Release:        2.35
Summary:        Mail Program
License:        GPL-2.0+
Group:          Productivity/Networking/Email/Clients
# ftp://ftp.mutt.org/mutt/devel/
Source0:        https://bitbucket.org/mutt/mutt/downloads/%name-%version.tar.gz
Source1:        Signature_conversion
Source2:        README.alternates
Source3:        mutt.png
Source4:        mutt.desktop
Source5:        skel.muttrc
Source6:        krb5-config
Source7:        mutt-1.5.21.de.po
Source8:        %name-%version-patches.tar.bz2
Source9:        mutt.mailcap
Patch:          %name-%version.dif
# http://www.spinnaker.de/mutt/compressed/
Patch1:         patch-%version.rr.compressed.bz2
Patch2:         %name-1.5.9i-pgpewrap.diff
Patch3:         %name-1.5.20-sendgroupreplyto.diff
Patch4:         %name-1.5.15-wrapcolumn.diff
# http://lunar-linux.org/mutt-sidebar
Patch6:         patch-1.5.24.sidebar.20140412.patch
Patch7:         mutt-1.5.24-opennfs.dif
Patch9:         bug-676388-largefile.patch
Patch10:        mutt-1.5.21-tinfo.dif
# http://www.wolfermann.org/mutt.html
Patch11:        aw.listreply.diff
Patch12:        patch-1.5.24.vk.pgp_verbose_mime
Patch14:        nion.sidebar-color.diff
# PATCH-FIX-OPENSUSE: bnc#813498 - mutt crashes in fgetwc in text_enriched_handler
Patch15:        widechar.sidebar.dif
# PATCH-FIX-OPENSUSE: Be able to read signed/encrypted messsages even with CRLF
Patch16:        mutt-1.5.23-cariage-return.path
# PATCH-FIX-OPENSUSE bnc#899712 - fallback mailcap for e.g text/html
Patch18:        mutt-1.5.21-mailcap.diff
# PATCH-FIX-SUSE: bsc#907453 - CVE-2014-9116: mutt: heap-based buffer overflow in mutt_substrdup()
Patch19:        bsc907453-CVE-2014-9116-jessie.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%global         _sysconfdir %{_sysconfdir}

%description
A very powerful mail user agent. It supports (among other nice things)
highlighting, threading, and PGP. It takes some time to get used to,
however.

%prep
%setup -q -n mutt-%version -b 8
for p in ../%name-%version-patches/*; do
    test -e $p || break
    echo Patch $p
    patch -s -p1 < $p
done
%patch
%patch1 -p0 -b .compressed
%patch2 -p0 -b .pgpewrap
%patch3 -p1 -b .sendgroupreplyto
%patch4 -p0 -b .wrapcolumn
%patch6 -p0 -b .sidebar
%patch7 -p0 -b .opennfs
%patch9 -p1 -b .largefile
%patch10 -p0 -b .tinfo
%patch11 -p1 -b .listreply
%patch12 -p0 -b .pgp_verbose_mtime
%patch14 -p2 -b .sidebar.color
%patch15 -p0 -b .widechar.sidebar
%patch16 -p0 -b .crlf
%patch18 -p1 -b .mailcap
%patch19 -p1 -b .cvw2014.9116

cp doc/Muttrc Muttrc.SuSE
cp %{S:2} .

%build
%if 0%{?suse_version} > 1100
autoreconf -fi
%endif
  cflags ()
  {
    local flag=$1; shift
    local var=$1; shift
    test -n "${flag}" -a -n "${var}" || return
    case "${!var}" in
    *${flag}*) return
    esac
    set -o noclobber
    case "$flag" in
    -Wl,*)
	if echo 'int main () { return 0; }' | \
	    ${CC:-gcc} -Werror $flag -o /dev/null -xc - > /dev/null 2>&1 ; then
	    eval $var=\${$var:+\$$var\ }$flag
	fi
	;;
    *)
	if ${CC:-gcc} -Werror $flag -S -o /dev/null -xc /dev/null > /dev/null 2>&1 ; then
	    eval $var=\${$var:+\$$var\ }$flag
	fi
    esac
    set +o noclobber
  }
CC=gcc
CFLAGS="-Wall $RPM_OPT_FLAGS -I. -D_GNU_SOURCE"
#cflags -DSUSE_IMAP_FORCE_SSL		CFLAGS
cflags -fno-strict-aliasing		CFLAGS
cflags -fstack-protector		CFLAGS
cflags -fPIE				CFLAGS
cflags -g3				CFLAGS
cflags -pipe				CFLAGS
cflags -Wl,--as-needed			LDFLAGS
cflags -Wl,-O2				LDFLAGS
cflags -Wl,--hash-size=8599		LDFLAGS
cflags -pie				LDFLAGS
KRB5CFGPATH=%{S:6}
export CC CFLAGS LDFLAGS KRB5CFGPATH
chmod 755 $KRB5CFGPATH
./configure $RPM_ARCH-suse-linux \
	--prefix=%{_prefix} \
	--datadir=%{_datadir} \
	--sysconfdir=%{_sysconfdir} \
	--mandir=%{_mandir} \
	--with-docdir=%{_docdir}/%name \
	--enable-imap \
	--enable-pop \
	--enable-pgp \
%if 0%{?suse_version} >= 1100
	--enable-gpgme \
%endif
	--enable-nfs-fix \
	--enable-mailtool \
	--enable-compressed \
	--disable-external-dotlock \
	--with-ssl=%{_prefix} \
	--with-sasl=%{_prefix} \
	--with-gss=%{_prefix} \
	--with-gnutls=%{_prefix} \
	--with-curses=%{_prefix} \
	--with-regex \
	--enable-smtp \
	--enable-hcache \
	--with-idn
make -C doc clean
make -C po update-po
cp %{S:7} po/de.po
make
make -C doc

%install
make install DESTDIR=%{buildroot}
mv Muttrc.SuSE %{buildroot}%{_sysconfdir}/Muttrc
install -m 755 %{S:1} %{buildroot}%{_bindir}
gzip -9 doc/manu*.txt
rm -f contrib/Makefile*
# datadir not automatically created:
mkdir -p %{buildroot}%{_datadir}/mutt
# INSTALL file should be removed:
rm -rf %{buildroot}%{_docdir}/%{name}/INSTALL
# mbox/mmdf manual page conflicts with the one from tin, so rename it
mv %{buildroot}%{_mandir}/man5/mbox.5 \
   %{buildroot}%{_mandir}/man5/mbox_mutt.5
mv %{buildroot}%{_mandir}/man5/mmdf.5 \
   %{buildroot}%{_mandir}/man5/mmdf_mutt.5
   %find_lang %name
# We get mime.types from aaa_base
rm -f %{buildroot}%{_sysconfdir}/mime.types
# Mutt BTS is gone
rm -f %{buildroot}%{_mandir}/man1/{flea*,muttbug*}
rm -f %{buildroot}%{_bindir}/{flea,muttbug}
rm -f %{buildroot}%{_sysconfdir}/Muttrc.dist
rm -f %{buildroot}%{_sysconfdir}/mime.types.dist
mkdir -p %{buildroot}%{_datadir}/pixmaps
install -m 644 %{SOURCE3} %{buildroot}%{_datadir}/pixmaps/
mkdir -p %{buildroot}%{_datadir}/applications
install -m 644 %{SOURCE4} %{buildroot}%{_datadir}/applications/
install -D -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/skel/.muttrc
install -D -m 644 %{SOURCE9} %{buildroot}%{_datadir}/mutt/mailcap
%suse_update_desktop_file mutt

%if 0%{?suse_version} >= 1140

%post
%mime_database_post

%postun
%mime_database_postun
%endif

%files -f %name.lang
%defattr(-,root,root)
%doc doc/manual*.html doc/manual.txt.gz COPYRIGHT README* NEWS TODO
%doc doc/PGP-Notes.txt doc/applying-patches.txt doc/devel-notes.txt
%config(noreplace) %{_sysconfdir}/skel/.muttrc
%{_bindir}/mutt
%{_bindir}/pgpewrap
%{_bindir}/pgpring
%{_bindir}/smime_keys
%{_bindir}/Signature_conversion
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/mutt.png
%{_mandir}/man1/mutt.1.gz
%{_mandir}/man1/pgp*.1.gz
%{_mandir}/man1/smime_keys.1.gz
%{_mandir}/man5/mmdf_mutt.5.gz
%{_mandir}/man5/muttrc.5.gz
%{_mandir}/man5/mbox_mutt.5.gz
%{_datadir}/mutt
%{_datadir}/mutt/mailcap
%config(noreplace) %{_sysconfdir}/Muttrc

%changelog
* Fri Sep 11 2015 werner@suse.de
- Update to mutt version 1.5.24
  + terminal status-line (TS) support, a.k.a. xterm title. see the
  following variables: $ts_enabled, $ts_icon_format, $ts_status_format
  ! $ssl_use_sslv3 is disabled by default.
  ! command-line arguments: -H now combines template and command-line
  address arguments.
  ! GnuPG signature name is set to signature.asc
  + New color object "prompt" added.
  + Ability to encrypt postponed messages.  See $postpone_encrypt and
  $postpone_encrypt_as.
  ! History ring now has a scratch buffer.
  ! mail-key is implemented for GPGME.  (Requires a recent GPGME).
  ! Removed GPG_AGENT_INFO check for GnuPG 2.1 compatibility.  Please
  set pgp_use_gpg_agent if using GnuPG 2.1 or later.
  ! $smime_encrypt_with now defaults to aes256.
  ! GnuPG fingerprints are used internally when possible.
  "--with-fingerprint" should be added to $pgp_list_pubring_command and
  $pgp_list_secring_command to enable this.  Please see contrib/gpg.rc.
  Fingerprints may also be used at the prompts for key selection.
  + $crypt_opportunistic_encrypt automatically enables/disables encryption
  based on message recipients.
  ! Attachments for signed, unencrypted emails may be deleted.
  ! Multiple crypt-hooks may be defined for the same regexp.
  This means multiple keys may be used for a recipient.
  + $crypt_confirmhook allows the confirmation prompt for crypt-hooks to
  be disabled.
  + $ssl_ciphers allows the SSL ciphers to be directly set.
  ! sime_keys better handles importing certificate chains.
  ! sime_keys now records certificate purposes (sign/encrypt).  Run
  "sime_keys refresh" to update smime index files.
  + $maildir_check_cur polls the maildir "cur" directory for new mail.
- Ported patches
  patch-1.5.21.vk.pgp_verbose_mime becomes patch-1.5.24.vk.pgp_verbose_mime
  patch-1.5.23.rr.compressed.bz2 becomes patch-1.5.24.rr.compressed.bz2
  patch-1.5.23.sidebar.20140412.patch becomes patch-1.5.24.sidebar.20140412.patch
  mutt-1.5.21-opennfs.dif becomes mutt-1.5.24-opennfs.dif
  mutt-1.5.23.dif becomes mutt-1.5.24.dif
- Modfied patches
  nion.sidebar-color.diff
  widechar.sidebar.dif
- Removed patch
  patch-1.5.23.xtitles.patch
* Mon Jan 26 2015 werner@suse.de
- Update to mutt version 1.5.23 which is a security bugfix release
  as well as add support for TLS 1.1/1.2
- Remove the patches automake-1.12.patch,
  mutt-1.5.20-gpgme_set_locale.patch, and mutt-CVE-2014-0467.patch
- Replace the patches
  patch-1.5.23.rr.compressed.bz2 with patch-1.5.21.rr.compressed.1.bz2
  mutt-1.5.21.sidebar.20120829.patch with patch-1.5.23.sidebar.20140412.patch
  patch-1.5.5.1.nt.xtitles.3.ab.1 with patch-1.5.23.xtitles.patch
  mutt-1.5.21.dif with mutt-1.5.23.dif
- Modify the patches aw.listreply.diff, bug-676388-largefile.patch,
  and bsc907453-CVE-2014-9116-jessie.patch
- Build with PIE
* Thu Dec  4 2014 werner@suse.de
- Add patch bsc907453-CVE-2014-9116-jessie.patch to fix bsc#907453
  CVE-2014-9116: heap-based buffer overflow in mutt_substrdup()
* Tue Nov 18 2014 lnussel@suse.de
- handle text/html by default (bnc#899712)
  that is add patch mutt-1.5.21-mailcap.diff
* Mon Mar 17 2014 meissner@suse.com
- mutt-CVE-2014-0467.patch: fixed a buffer overflow during header display.
  CVE-2014-0467 / bnc#868115
* Mon Aug  5 2013 ro@suse.de
- BuildRequire libgcrpyt-devel instead of libgcrypt for > 12.3
* Wed May 29 2013 werner@suse.de
- Enable mutt to parse e.g. PGP markers with CRLF
* Thu Apr 18 2013 werner@suse.de
- Add widechar.sidebar.dif as workaround: bnc#813498 - mutt crashes
  in fgetwc in text_enriched_handler
* Mon Jan 14 2013 werner@suse.de
- Remove spurious blank line from new patch to make older patch(1)
  also work with this
- Make it build with older products
* Tue Dec 18 2012 aginies@suse.com
- update sidebar to version 20120829
* Tue Sep 18 2012 vmiklos@suse.cz
- Add back lost sidebar color patch.
* Thu Jun 21 2012 asn@cryptomilk.org
- Update sidebar patch.
* Tue May 29 2012 puzel@suse.com
- fix build with automake-1.12
  - add: automake-1.12.patch
* Fri Apr 13 2012 multiple1902@gmail.com
- Added patch automatically add a filename and description to PGP/MIME attachments.
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Nov 24 2011 vmiklos@vmiklos.hu
- Add patch to introduce a new (optional) check when
  replying to messages originating from a mailing list
* Tue Nov 22 2011 werner@suse.de
- Add patch to use libtinfo if available
* Tue Oct 25 2011 vmiklos@vmiklos.hu
- Add patch to be able to specify the color of the sidebar
* Thu Jul  7 2011 werner@suse.de
- Update patch for Mutt Ticket #3288 and check for empty headers
  in mx_update_context() (bnx#704359)
* Mon Jun 20 2011 werner@suse.de
- Add patches for the following Mutt Tickets:
  [#1771]: pipe-mime
  [#2179]: score-match
  [#3240]: imapuser
  [#3261]: readonly-open
  [#3288]: mx_update_context-segfault
  [#3293]: dont-recode-saved-attachments
  [#3300]: gpgme-1.2
  [#3324]: smimekeys-tmpdir
  [#3326]: emptycharset
  [#3335]: thread-segfault
  [#3339]: smime_keys-chaining
  [#3371]: ansi-escape-segfault
  [#3378]: references
  [#3457]: pop3-segfault
  [#3459]: split-fetches
  [#3483]: header-strchr
  [#3496]: no-implicit_autoview-for-text-html
  [#3506]: gnutls-CN-validation
  [#3515]: gnutls-deprecated-set-priority
  [#3516]: gnutls-deprecated-verify-peers
  with ticket #3506 bnc#700648 becomes fixed, with ticket #3496
  the autoview regression for text/html should be fixed.
- Add one line more for sidebar if displayed on top
* Fri Apr 15 2011 werner@suse.de
- Support offsets in 2gig mbox files even on 32bit architectures (bnc#676388)
* Thu Feb  3 2011 ro@suse.de
- buildrequire gdbm-devel also on 11.4 to fix build
* Wed Feb  2 2011 werner@suse.de
- Switch from buildrequires gpgme-devel to libgpgme-devel for 11.4
- Work around missing buildrequires of libgpgme-devel by adding
  libassuan-devel for 11.4
* Mon Jan 31 2011 gber@opensuse.org
- recommend smtp_daemon since mutt has builtin SMTP support
* Mon Jan 31 2011 werner@suse.de
- Fix the orther sidebar patch as it is broken with MALLOC_CHECK=1
  now static buffers are used instead (re)alloced arrays.
* Wed Jan 26 2011 gber@opensuse.org
- fix build by removing Makefiles from contrib
- added missing %%mime_database_post/%%mime_database_postun
* Wed Jan 26 2011 gber@opensuse.org
- modified desktop file so mutt can be used as the default mailto
  handler
* Fri Nov 26 2010 pth@suse.de
- Update and fix the german translation.
- Update all translations so that the user edits the right translation.
* Thu Nov  4 2010 werner@suse.de
- Update to mutt version 1.5.21 which include last three fixes
  * Beside this better support of S/MIME certificates
- Use an other sidebar patch found for OpenBSD
- Update our patches
* Mon May 10 2010 guido+opensuse.org@berhoerster.name
- add proper category to desktop file
* Mon Apr 19 2010 lnussel@suse.de
- fix build against openssl 1.0
* Wed Dec  2 2009 werner@suse.de
- Do not fold From lines into wrong format (bnc#559525)
* Wed Nov 25 2009 werner@suse.de
- Update for bnc#537141: do not add certificates with wrong hosts
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Sep  9 2009 werner@suse.de
- Fix incorrectly handling of \0 character in SSL certificate (bnc#537141)
* Wed Jul 15 2009 werner@suse.de
- Make gpgme work even with locale, patch from Evan McClain
  (bnc#519628)
* Fri Jun 26 2009 werner@suse.de
- Update to mutt version 1.5.20 which include last fix
* Tue Apr 21 2009 werner@suse.de
- Upstream fix to make mutt showing new message count (bnc#487718)
* Tue Mar  3 2009 werner@suse.de
- updated to mutt version 1.5.19 mostly a bugfix release
- updated sidebar patch to 1.5.18.sidebar.20080611
  * make it work with 1.5.19
  * make sidebar-fix also work
- updated compression patch to patch-1.5.19.rr.compressed
- enable smtp support
- enable mixmaster support
- use regex(7) of glibc
* Thu Apr 10 2008 werner@suse.de
- Avoid trouble with krb5-config
* Thu Dec 20 2007 bwalle@suse.de
- updated to mutt version 1.5.17 the bug fix release
- updated sidebar patch to 1.5.17.sidebar.20071102
- updated compression patch to 1.5.17.rr.compressed.1
* Wed Dec  5 2007 ro@suse.de
- moved /etc/skel/.muttrc to this package
* Thu Sep 20 2007 werner@suse.de
- Replace handmade sidebar patch with oringnal one
- Set check_mbox_sizes to make mutt backward compatible (#326697)
- Use imap_force_ssl alias for ssl_force_tls even in 10.3
* Thu Jun 21 2007 werner@suse.de
- Update to mutt version 1.5.16 the bug fix version
* Fri Jun  1 2007 werner@suse.de
- Update to mutt version 1.5.15 due CVE-2007-1558 (bug #279843)
* Wed May 16 2007 werner@suse.de
- Overflow: don't compare signed with unsigned (bug #275069)
* Fri Mar 23 2007 rguenther@suse.de
- add gdbm-devel and ncurses-devel BuildRequires
* Mon Feb 26 2007 stbinner@suse.de
- fix build by including icon and .desktop into package
* Thu Nov 16 2006 werner@suse.de
- Make sidebar fix smarter by not breaking new status (bug #221599)
* Thu Nov  9 2006 werner@suse.de
- Do security check for opening files on NFS file systems (#210159)
- Reenable SASL and GSSAPI
- Make LOGIN work even if SASL is enabled
- Make mutt use ispell again
- Update the sidebar patch
- Avoid reads of mailboxes if no sidebar is enabled (#215261)
* Fri Sep 15 2006 werner@suse.de
- Enable libgpgme (bug #203486)
* Mon Aug 28 2006 werner@suse.de
- Add sidebar patch to mutt to have the mailboxes around
- Make the old variable imap_force_ssl an alias to ssl_force_tls
  for older SuSE distributions
* Thu Aug 17 2006 werner@suse.de
- Update to mutt 1.5.13
  * Various fixes in imap handling
* Mon Jul 17 2006 werner@suse.de
- Update to mutt 1.5.12
  * Include previous security fixes
  * Fix bug in curses handling
  * Better caching of mail bodies
  * Remove memory leaks
* Thu Jun 29 2006 werner@suse.de
- Update to mutt 1.5.11
* Wed Jun 28 2006 werner@suse.de
- Fix mutt IMAP buffer overflow in namespace parsing (bug #188872)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 mmj@suse.de
- Compile with -fstack-protector
* Tue Nov 29 2005 sbrabec@suse.cz
- Don't package icon already present in desktop-data-SuSE.
  Cleans rpm -V output.
* Mon Oct 10 2005 mmj@suse.de
- Readd -fno-strict-aliasing
* Mon Oct  3 2005 mmj@suse.de
- Signatures with no newline should not cause mutt to think
  it's a changed message [#117451]
* Thu Jul 28 2005 mmj@suse.de
- Add patch to set term window title bar with the mbox name [#98557]
* Sun Jul 24 2005 mmj@suse.de
- Fix segfault with S/Mime [#87177]
* Fri Jul  8 2005 mmj@suse.de
- Remove bogus hunk from imap race fix patch
* Mon Jun 27 2005 mmj@suse.de
- Add patch from Thomas Glanzmann to fix imap crashes
* Mon May  9 2005 mmj@suse.de
- Add patch for wrapcolumn by Manfred Hollstein
* Tue Mar 15 2005 mmj@suse.de
- Update to 1.5.9
* Mon Feb 28 2005 mmj@suse.de
- Make sure a pointer is not NULL before we start referencing it
* Mon Feb 14 2005 mmj@suse.de
- Update to 1.5.8
* Fri Feb 11 2005 mmj@suse.de
- Disable inode sort due to recommendations from the header
  cache developer
* Fri Feb  4 2005 mmj@suse.de
- Update header cache patch and fix build in PLUS
* Wed Feb  2 2005 mmj@suse.de
- Rename mmdf.5 -> mmdf_mutt.5 to not conflict with tin
* Tue Feb  1 2005 mmj@suse.de
- Update to 1.5.7
* Tue Jan 11 2005 mmj@suse.de
- Fix plain auth for sasl with patch from HEAD [#49573]
- Update header cache patch to latest
* Wed Nov 17 2004 mmj@suse.de
- Package pixmaps
* Sat Oct 23 2004 mmj@suse.de
- Switch heimdal-* to kerberos-devel-packages in #nfb as pr. requst
  of Mr. Carsten Höger
* Tue Aug 31 2004 mmj@suse.de
- Update to a new version with bugfixes of the header cache patch
* Wed Aug 18 2004 mmj@suse.de
- Apply a new version of the header cache patch that also supports
  IMAP.
* Fri Jul  2 2004 mmj@suse.de
- Using upstream fix for problem with stat() on source files
  which could contain extra chars such as pipe [#42658]
* Sat Jun  5 2004 mmj@suse.de
- Enable idn support [#41456]
* Thu May 13 2004 mmj@suse.de
- Add maildir header cache patch from
  Thomas Glanzmann <sithglan@stud.uni-erlangen.de>
- Don't remove buildroot in %%install
- Don't strip when installing
* Wed Apr 21 2004 mmj@suse.de
- When requiring postfix, don't install sendmail
* Thu Apr 15 2004 mmj@suse.de
- Add the contrib/ directory to the documentation [#38955]
* Fri Mar 26 2004 mmj@suse.de
- Add # postfix to neededforbuild
* Mon Feb 16 2004 mmj@suse.de
- People are going to ask over and over again about the alternates
  error, even though it's documented in the manual page, so install
  /usr/share/doc/packages/mutt/README.alternates
* Wed Feb  4 2004 mmj@suse.de
- Readd cast that got lost when 99%% of a patch was merged upstream
* Wed Feb  4 2004 mmj@suse.de
- Update to 1.5.6
- Include patch from Joël Riou <joel.riou@normalesup.org> which
  adds a variable config_charset that one may define in a rc file
  that contains non ascii characters (aliases files for
  instance). Where a rc file is sourced, the commands are
  converted from this encoding, so that it works well if you are
  used to working in UTF8 xterms but sometimes have to use a
  latin-encoded terminal.
* Mon Nov 17 2003 mmj@suse.de
- Use rr.compressed for 1.5.5.1 from the author
* Wed Nov  5 2003 mmj@suse.de
- Update to mutt-1.5.5.1i which includes the missing files
* Wed Nov  5 2003 mmj@suse.de
- Update to mutt-1.5.5i which is the last planned development snap-
  shot.
- Remove included/obsoleted patches
- Don't strip explicitly
- For now include snprintf.c and regex.c, they were forgotten in the
  mutt tarball.
* Wed Oct 15 2003 mmj@suse.de
- Don't build as root
- Cleanup specfile a bit
* Thu Sep 18 2003 mmj@suse.de
- Fix head syntax [#31228]
* Tue Sep  9 2003 pthomas@suse.de
- Fix for real :(
* Tue Sep  9 2003 pthomas@suse.de
- Fix the type-punning patch.
* Thu Sep  4 2003 sndirsch@suse.de
- fixed attaching signature; ".signature" must be "~/.signature"
* Sat Aug 16 2003 adrian@suse.de
- install desktop file from kappfinder
* Fri Aug 15 2003 ro@suse.de
- changed neededforbuild: cyrus-sasl
* Wed Aug 13 2003 pthomas@suse.de
- Fix all cases of (unnecessary) type-punning, thus no need for
  - fno-strict-aliasing.
- Include stdlib.h in lib.h for declaration of exit.
- Fix permissions for mutt-1.4.1i-authsasl.diff
* Wed Aug 13 2003 mmj@suse.de
- Add a better fix from Brendan Cully to fix [#25026]
- Add -fno-strict-aliasing
* Sat Jul 26 2003 kukuk@suse.de
- cryus-sasl2 was renamed to cyrus-sasl
* Wed Jul 16 2003 mmj@suse.de
- Add patch from Brendan Cully to fix DIGEST-MD5 sasl
  authentication. [#25026]
* Wed Jun 11 2003 mmj@suse.de
- Rename mbox.5 to mbox_mutt.5 to avoid conflict with tin
- Use %%find_lang macro
* Mon Jun  2 2003 mmj@suse.de
- Add script from Mike Fabian to handle UTF-8 encodings back and
  forth [#27140]
* Tue May 13 2003 mmj@suse.de
- Use %%defattr
- Package muttbug
* Tue Apr 15 2003 ro@suse.de
- fixed neededforbuild
* Fri Mar 21 2003 mmj@suse.de
- Update to 1.4.1 which primarily fixes the imap/utf7.c buffer-
  overflow.
* Thu Jan 23 2003 mmj@suse.de
- Add --enable-buffy-size which got lost because the maintainer
  kept several versions around
* Thu Jan 23 2003 mmj@suse.de
- Add patch to use sasl2 instead og sasl
* Sun Jan  5 2003 mmj@suse.de
- Below action was not A Good Thing[tm] for all, so made it a
  configure option again.
* Fri Nov 15 2002 mmj@suse.de
- Fold the group reply patch in to always be default behaviour
* Fri Nov  8 2002 mmj@suse.de
- Apply fresh 1.4 compressed folder patch instead of 1.3.99 repatch
* Sat Nov  2 2002 mmj@suse.de
- Better version from ME of longline patch
* Fri Nov  1 2002 mmj@suse.de
- Add patch from Michael Elkins to allow lines > 255 [#16030]
- Make patches have a unique name
- Trim the neededforbuild
* Fri May 31 2002 ro@suse.de
- changed neededforbuild <slang> to <slang slang-devel>
* Fri May 31 2002 mmj@suse.de
- Disabled patches that broke IMAP support.
* Wed May 29 2002 mmj@suse.de
- Updated to the next STABLE Mutt release 1.4, which includes
  improved IMAP and POP support. Better maildir handling,
  improved threading. And lots more, which is better summarized
  on http://www.mutt.org
* Tue May 28 2002 mmj@suse.de
- Added a patch to allow longer lines [Bug #16030]
- Added a patch to allow mailboxes > 2 GB [Bug #16356]
* Tue May 14 2002 mmj@suse.de
- Added a patch from Matthias Eckermann to include the original
  To: field in the new To: when doing group reply, and the boolean
  'send_group_reply_to' is set.
* Fri May  3 2002 mmj@suse.de
- Update to 1.3.99 which is just bugfix release towards 1.4
* Wed Apr  3 2002 mmj@suse.de
- automake/autoconf fix. Use AC_LIBOBJ instead of LIBOBJS.
* Wed Mar 20 2002 mmj@suse.de
- Fix segfault in pgpewrap when invoked with incorrect arguments.
  Fixes Bug #15213, patch from axboe@
* Wed Mar 13 2002 mmj@suse.de
- Make /etc/Muttrc %%config(noreplace)
* Wed Mar 13 2002 mmj@suse.de
- Updated to 1.3.28
* Sun Feb 24 2002 mmj@suse.de
- Re-added patches known to work very well, but that was left out
  to evaluate vanilla 1.3.27i:
  - Compressed folder support
  - Iconv patch that fixes qp problems in multibyte locales
* Thu Feb 14 2002 schwab@suse.de
- Don't add /usr/include to include search path.
* Mon Feb  4 2002 mmj@suse.de
- Updated to newest beta-release 1.3.27
* Wed Jan  2 2002 poeml@suse.de
- add patch-1.2,3.rfc822_terminate.1 which fixes a remote
  exploitable string buffer overflow
  (minus hunks #8 and #10 which are already in 1.3.22.1)
* Tue Sep 18 2001 bjacke@suse.de
- fix a possible segfault for a certain search pattern
- fix a possible crash scenario when using gpg and attachments
* Tue Sep  4 2001 bjacke@suse.de
- fix some memory leaks in imap code
- fix bug where non-regular files could be attached
- po updates
* Sat Sep  1 2001 bjacke@suse.de
- update to 1.3.22.1
* Thu Aug 23 2001 bjacke@suse.de
- update to 1.3.21 which fixes some MH bugs and others
* Mon Aug 13 2001 ro@suse.de
- changed neededforbuild <sp_libs> to <sp-devel>
* Thu Jul 26 2001 bjacke@suse.de
- update to 1.3.20
- patched to speed up mbox-sort from n^2 to n*log(n)
* Sat Apr 28 2001 bjacke@suse.de
- another l10n fix
- save manuals gzipped
* Wed Apr 25 2001 mfabian@suse.de
- remove "fuzzy" in header of ja.po. When the header is marked
  as "fuzzy", the charset will not be written to the .mo file
  and mutt will not show Japanese messages correctly.
- don't convert string received from gettext again, the new
  version of gettext already does the conversion to the charset
  of the current locale.
* Thu Apr 19 2001 bjacke@suse.de
- fixed a buffer underrun
- fixed possible segfault (#6979)
- redisabled buffy fix
* Sun Mar 25 2001 bjacke@suse.de
- update to 1.3.16i
- dropped superfluous additional options patch
- add compressed folder patch
- activated buffy fix to circumvent recent NFS a-time problems
* Wed Jan 31 2001 bjacke@suse.de
- fixed version in specfile
* Thu Jan 25 2001 bjacke@suse.de
- dropped tmp patch wich did more bad than good
* Wed Jan 10 2001 bjacke@suse.de
- fixed latest fix
* Tue Jan  9 2001 bjacke@suse.de
- applied tmp file patch
- added smtp_daemon to requires
* Mon Dec 18 2000 bjacke@suse.de
- merged muttssl and mutt
* Mon Dec 11 2000 bjacke@suse.de
- enable fcntl and disable flock locking
* Tue Nov 28 2000 bjacke@suse.de
- update to 1.3.12i due to glibc 2.2 locale issues
- fixed neededforbuild (bug 4254)
- minor specfile changes
* Mon Sep  4 2000 vinil@suse.cz
- czech po file corrected
* Mon Jul 31 2000 werner@suse.de
- Update to 1.2.5i due bug fixes (IMAP, SIGSEGV in curs_main.c)
* Fri Jul  7 2000 werner@suse.de
- Update to 1.2.4i due to fixes (IMAP, SSL, ...) done in 1.2.3
  and 1.2.4
* Thu Jun 29 2000 werner@suse.de
- Split spec of mutt and muttssl to avoid conflicts during build
- Use different build root to avoid mixed versions
- Update to 1.2.2i to avoid bugs in SSL code, core dumps, and
  mailbox corruption
* Mon May 15 2000 werner@suse.de
- Update to new version 1.2i
  * move changes to 1.2i
  * enable SSL for imap
  * add *.rc from contrib path to doc (samples for pgp using)
- Split mutt into mutt and muttssl
* Wed Mar  8 2000 werner@suse.de
- Disable --enable-exact-address because it fools the users by
  asking questions for nothing.
* Tue Feb 22 2000 werner@suse.de
- Fix programming bug: ncurses now does what the docu says.
  Therefore use_default_color() should be called only once
  after start_color().
* Tue Jan 25 2000 werner@suse.de
- New version 1.0.1i with some minor bug fixes
* Tue Jan 25 2000 kasal@suse.de
- urlview moved to a new package
* Tue Jan 18 2000 werner@suse.de
- /usr/man -> /usr/share/man
- target is ${RPM_ARCH}-suse-linux and nothing more
* Tue Jan 18 2000 werner@suse.de
- New mutt version 1.0i
  * patch for two letter year (e.g. 00)
- New urlview version
  * A SuSE url_handler.sh script
  * A SuSE urlview.conf
* Mon Oct 18 1999 garloff@suse.de
- highlight_unread sometimes didn't work. Fixed.
* Thu Oct 14 1999 garloff@suse.de
- Added contrib/Pine.rc and Mush.rc to as %%docs
* Wed Oct 13 1999 garloff@suse.de
- Two new options: "delete_tilde" and "highlight_unread".
  The meaning is obvious ...
* Fri Oct  1 1999 werner@suse.de
- Added gpg in neededforbuild to get both pgp and gpg
  path included into mutt.
* Tue Sep 28 1999 werner@suse.de
- Put urlview into mutt package
- Use changes Muttrc instead of my.Muttrc
  * there is no variable web_browser anymore
- Require ispell to get spell feature
- A few sample muttrc and urlview(rc) for aaa_skel
* Tue Sep 28 1999 ro@suse.de
- update to 1.0pre3
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jul 20 1999 florian@suse.de
- update to 0.95.6i
* Wed Apr 14 1999 ro@suse.de
- use gettext in neededforbuilt (builtin won't work)
* Tue Apr  6 1999 ro@suse.de
- update to 0.95.4i
* Thu Dec  3 1998 bs@suse.de
- added sp and sp_libs to neededforbuild
* Wed Dec  2 1998 bs@suse.de
- use sgmtools instead of linuxdoc for build
* Wed Jul 29 1998 florian@suse.de
- add security patch
* Sun Jul 19 1998 florian@suse.de
- update to version 0.93.1i
* Thu Feb  5 1998 florian@suse.de
- update to version 0.89.1
* Thu Oct  9 1997 florian@suse.de
- update to version 0.85
* Tue May 20 1997 florian@suse.de
- update to version 0.74
* Sun Apr 13 1997 florian@suse.de
- update to new version 0.69
* Tue Jan 28 1997 florian@suse.de
- update to new version 0.59
- pgp-support is enabled
* Thu Jan  2 1997 florian@suse.de
- update to version 0.52
* Thu Jan  2 1997 florian@suse.de
- update to version 0.51
* Thu Jan  2 1997 florian@suse.de
- update to version 0.50
* Thu Jan  2 1997 florian@suse.de
- update to version 0.49
* Thu Jan  2 1997 florian@suse.de
- Neue Version 0.48.1 mit vielen Veraenderungen.
- Anpassungen fuer eine korrekte Host-Absenderadresse.
- Umstieg auf non-sgid-mail spool-Verzeichnis.
* Thu Jan  2 1997 florian@suse.de
- update to newer version
  Mon Sep  2 03:06:07 MET DST 1996
  new version.
